pub(super) fn check_dir_writable(dir: &Path) -> Result<(), InstallerError>Expand description
Verifies that dir is writable by creating a temporary file in it.
pub(super) fn check_dir_writable(dir: &Path) -> Result<(), InstallerError>Verifies that dir is writable by creating a temporary file in it.